@@ -31,5 +31,5 @@ _underline_
 \\_escape style_
 """
 
-TRUST_EVERYTHING = False
-TRUST_EVERYTHING__DOC = "Always trust new encryption keys. This is unsafe if you need perfect bridge to end encryption."
+REACTION_CACHE_SIZE = 10000
+REACTION_CACHE_SIZE__DOC = "Emoji reaction cache size, in number of messages"
