@@ -33,7 +33,9 @@ class Gateway(BaseGateway):
     COMPONENT_NAME = "Matrix (slidge)"
     COMPONENT_TYPE = "matrix"
 
-    COMPONENT_AVATAR = "https://upload.wikimedia.org/wikipedia/commons/thumb/7/7c/Matrix_icon.svg/209px-Matrix_icon.svg.png"
+    COMPONENT_AVATAR = (
+        "https://codeberg.org/slidge/matridge/raw/branch/main/assets/matrix_outline.png"
+    )
 
     ROSTER_GROUP: str = "matrix"
 
